@@ -1,12 +1,13 @@
 package Padre::Plugin::Git::Output;
 
 use v5.10;
-use strictures 1;
+use strict;
+use warnings;
 
 use Padre::Unload ();
 use Padre::Plugin::Git::FBP::Output ();
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 use parent qw(
 	Padre::Plugin::Git::FBP::Output
 	Padre::Plugin
@@ -20,7 +21,7 @@ sub new {
 	my $main  = shift;
 	my $title = shift || '';
 	my $text  = shift || '';
-	
+
 	# Create the dialogue
 	my $self = $class->SUPER::new($main);
 
@@ -42,13 +43,15 @@ Perl programming -> TIOBE
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Padre::Plugin::Git::Output - Git plugin for Padre, The Perl IDE.
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
@@ -82,20 +85,19 @@ etc.), refer to L<Padre::Plugin::Git>.
 
 =head1 AUTHOR
 
-Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
+See L<Padre::Plugin::Git>
 
-=head1 COPYRIGHT AND LICENSE
+=head2 CONTRIBUTORS
 
-Copyright (c) 2012 kevin dawson, all rights reserved.
+See L<Padre::Plugin::Git>
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+=head1 COPYRIGHT
+
+See L<Padre::Plugin::Git>
+
+=head1 LICENSE
+
+See L<Padre::Plugin::Git>
 
 =cut
 
-
-# Copyright 2008-2012 The Padre development team as listed in Padre.pm.
-# LICENSE
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl 5 itself.
-
