@@ -1,10 +1,11 @@
 package Padre::Plugin::Git::Task::Git_cmd;
 
 use v5.10;
-use strictures 1;
+use strict;
+use warnings;
 
 use Carp qw( croak );
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Padre::Task   ();
 use Padre::Unload ;
@@ -52,7 +53,7 @@ sub run {
 		$git_cmd->{output} = $git_cmd->{error};
 		$git_cmd->{error}  = undef;
 	}
-	
+
 	#saving to $self makes thing availbe to on_finish under $task
 
 	$self->{error}  = $git_cmd->{error};
@@ -70,13 +71,15 @@ Perl programming -> TIOBE
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Padre::Plugin::Git::Task::Git_cmd - Git plugin for Padre, The Perl IDE.
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -123,19 +126,18 @@ etc.), refer to L<Padre::Plugin::Git>.
 
 =head1 AUTHOR
 
-Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
+See L<Padre::Plugin::Git>
 
+=head2 CONTRIBUTORS
 
-=head1 COPYRIGHT AND LICENSE
+See L<Padre::Plugin::Git>
 
-Copyright 2008-2012 The Padre development team as listed in Padre.pm.
+=head1 COPYRIGHT
 
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
+See L<Padre::Plugin::Git>
+
+=head1 LICENSE
+
+See L<Padre::Plugin::Git>
 
 =cut
-
-# Copyright 2008-2012 The Padre development team as listed in Padre.pm.
-# LICENSE
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl 5 itself.
